## 0.13.0.3 (2023-07-20)

Add an upstream_repository field to METADATA.toml (#10487)

Closes: #10478

## 0.13.0.2 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 0.13.0.1 (2022-10-28)

xmltodict: improve parse input types (#9018)

## 0.13.0 (2022-06-26)

Bump xmltodict to 0.13.* (#8172)

## 0.12.2 (2022-06-25)

appdirs, tabulate, termcolor, xmltodict: check missing defs (#8156)

complete termcolor, xmltodict

## 0.12.1 (2022-04-16)

Third-party stubs: import from `collections.abc` where possible (#7637)

## 0.12.0 (2022-03-11)

Add xmltodict (#7472)

Signed-off-by: Andrej Shadura <andrew.shadura@collabora.co.uk>

